evaluation

package
v0.0.0-...-71ec521 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 11, 2023 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the evaluation type in the database.
	Label = "evaluation"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldUserId holds the string denoting the userid field in the database.
	FieldUserId = "user_id"
	// FieldResponseId holds the string denoting the responseid field in the database.
	FieldResponseId = "response_id"
	// FieldExternalId holds the string denoting the externalid field in the database.
	FieldExternalId = "external_id"
	// FieldDate holds the string denoting the date field in the database.
	FieldDate = "date"
	// FieldEvaluationResult holds the string denoting the evaluationresult field in the database.
	FieldEvaluationResult = "evaluation_result"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeResponse holds the string denoting the response edge name in mutations.
	EdgeResponse = "response"
	// Table holds the table name of the evaluation in the database.
	Table = "evaluations"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "evaluations"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
	// ResponseTable is the table that holds the response relation/edge.
	ResponseTable = "evaluations"
	// ResponseInverseTable is the table name for the Response entity.
	// It exists in this package in order to avoid circular dependency with the "response" package.
	ResponseInverseTable = "responses"
	// ResponseColumn is the table column denoting the response relation/edge.
	ResponseColumn = "response_id"
)

Variables

Columns holds all SQL columns for evaluation fields.

var (
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Functions

func And

func And(predicates ...predicate.Evaluation) predicate.Evaluation

And groups predicates with the AND operator between them.

func Date

func Date(v time.Time) predicate.Evaluation

Date applies equality check predicate on the "date" field. It's identical to DateEQ.

func DateEQ

func DateEQ(v time.Time) predicate.Evaluation

DateEQ applies the EQ predicate on the "date" field.

func DateGT

func DateGT(v time.Time) predicate.Evaluation

DateGT applies the GT predicate on the "date" field.

func DateGTE

func DateGTE(v time.Time) predicate.Evaluation

DateGTE applies the GTE predicate on the "date" field.

func DateIn

func DateIn(vs ...time.Time) predicate.Evaluation

DateIn applies the In predicate on the "date" field.

func DateIsNil

func DateIsNil() predicate.Evaluation

DateIsNil applies the IsNil predicate on the "date" field.

func DateLT

func DateLT(v time.Time) predicate.Evaluation

DateLT applies the LT predicate on the "date" field.

func DateLTE

func DateLTE(v time.Time) predicate.Evaluation

DateLTE applies the LTE predicate on the "date" field.

func DateNEQ

func DateNEQ(v time.Time) predicate.Evaluation

DateNEQ applies the NEQ predicate on the "date" field.

func DateNotIn

func DateNotIn(vs ...time.Time) predicate.Evaluation

DateNotIn applies the NotIn predicate on the "date" field.

func DateNotNil

func DateNotNil() predicate.Evaluation

DateNotNil applies the NotNil predicate on the "date" field.

func EvaluationResult

func EvaluationResult(v string) predicate.Evaluation

EvaluationResult applies equality check predicate on the "evaluationResult" field. It's identical to EvaluationResultEQ.

func EvaluationResultContains

func EvaluationResultContains(v string) predicate.Evaluation

EvaluationResultContains applies the Contains predicate on the "evaluationResult" field.

func EvaluationResultContainsFold

func EvaluationResultContainsFold(v string) predicate.Evaluation

EvaluationResultContainsFold applies the ContainsFold predicate on the "evaluationResult" field.

func EvaluationResultEQ

func EvaluationResultEQ(v string) predicate.Evaluation

EvaluationResultEQ applies the EQ predicate on the "evaluationResult" field.

func EvaluationResultEqualFold

func EvaluationResultEqualFold(v string) predicate.Evaluation

EvaluationResultEqualFold applies the EqualFold predicate on the "evaluationResult" field.

func EvaluationResultGT

func EvaluationResultGT(v string) predicate.Evaluation

EvaluationResultGT applies the GT predicate on the "evaluationResult" field.

func EvaluationResultGTE

func EvaluationResultGTE(v string) predicate.Evaluation

EvaluationResultGTE applies the GTE predicate on the "evaluationResult" field.

func EvaluationResultHasPrefix

func EvaluationResultHasPrefix(v string) predicate.Evaluation

EvaluationResultHasPrefix applies the HasPrefix predicate on the "evaluationResult" field.

func EvaluationResultHasSuffix

func EvaluationResultHasSuffix(v string) predicate.Evaluation

EvaluationResultHasSuffix applies the HasSuffix predicate on the "evaluationResult" field.

func EvaluationResultIn

func EvaluationResultIn(vs ...string) predicate.Evaluation

EvaluationResultIn applies the In predicate on the "evaluationResult" field.

func EvaluationResultLT

func EvaluationResultLT(v string) predicate.Evaluation

EvaluationResultLT applies the LT predicate on the "evaluationResult" field.

func EvaluationResultLTE

func EvaluationResultLTE(v string) predicate.Evaluation

EvaluationResultLTE applies the LTE predicate on the "evaluationResult" field.

func EvaluationResultNEQ

func EvaluationResultNEQ(v string) predicate.Evaluation

EvaluationResultNEQ applies the NEQ predicate on the "evaluationResult" field.

func EvaluationResultNotIn

func EvaluationResultNotIn(vs ...string) predicate.Evaluation

EvaluationResultNotIn applies the NotIn predicate on the "evaluationResult" field.

func ExternalId

func ExternalId(v string) predicate.Evaluation

ExternalId applies equality check predicate on the "externalId" field. It's identical to ExternalIdEQ.

func ExternalIdContains

func ExternalIdContains(v string) predicate.Evaluation

ExternalIdContains applies the Contains predicate on the "externalId" field.

func ExternalIdContainsFold

func ExternalIdContainsFold(v string) predicate.Evaluation

ExternalIdContainsFold applies the ContainsFold predicate on the "externalId" field.

func ExternalIdEQ

func ExternalIdEQ(v string) predicate.Evaluation

ExternalIdEQ applies the EQ predicate on the "externalId" field.

func ExternalIdEqualFold

func ExternalIdEqualFold(v string) predicate.Evaluation

ExternalIdEqualFold applies the EqualFold predicate on the "externalId" field.

func ExternalIdGT

func ExternalIdGT(v string) predicate.Evaluation

ExternalIdGT applies the GT predicate on the "externalId" field.

func ExternalIdGTE

func ExternalIdGTE(v string) predicate.Evaluation

ExternalIdGTE applies the GTE predicate on the "externalId" field.

func ExternalIdHasPrefix

func ExternalIdHasPrefix(v string) predicate.Evaluation

ExternalIdHasPrefix applies the HasPrefix predicate on the "externalId" field.

func ExternalIdHasSuffix

func ExternalIdHasSuffix(v string) predicate.Evaluation

ExternalIdHasSuffix applies the HasSuffix predicate on the "externalId" field.

func ExternalIdIn

func ExternalIdIn(vs ...string) predicate.Evaluation

ExternalIdIn applies the In predicate on the "externalId" field.

func ExternalIdIsNil

func ExternalIdIsNil() predicate.Evaluation

ExternalIdIsNil applies the IsNil predicate on the "externalId" field.

func ExternalIdLT

func ExternalIdLT(v string) predicate.Evaluation

ExternalIdLT applies the LT predicate on the "externalId" field.

func ExternalIdLTE

func ExternalIdLTE(v string) predicate.Evaluation

ExternalIdLTE applies the LTE predicate on the "externalId" field.

func ExternalIdNEQ

func ExternalIdNEQ(v string) predicate.Evaluation

ExternalIdNEQ applies the NEQ predicate on the "externalId" field.

func ExternalIdNotIn

func ExternalIdNotIn(vs ...string) predicate.Evaluation

ExternalIdNotIn applies the NotIn predicate on the "externalId" field.

func ExternalIdNotNil

func ExternalIdNotNil() predicate.Evaluation

ExternalIdNotNil applies the NotNil predicate on the "externalId" field.

func HasResponse

func HasResponse() predicate.Evaluation

HasResponse applies the HasEdge predicate on the "response" edge.

func HasResponseWith

func HasResponseWith(preds ...predicate.Response) predicate.Evaluation

HasResponseWith applies the HasEdge predicate on the "response" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.Evaluation

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.Evaluation

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Evaluation

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Evaluation

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Evaluation

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Evaluation

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Evaluation

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Evaluation

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Evaluation

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Evaluation

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Evaluation) predicate.Evaluation

Or groups predicates with the OR operator between them.

func ResponseId

func ResponseId(v uuid.UUID) predicate.Evaluation

ResponseId applies equality check predicate on the "responseId" field. It's identical to ResponseIdEQ.

func ResponseIdEQ

func ResponseIdEQ(v uuid.UUID) predicate.Evaluation

ResponseIdEQ applies the EQ predicate on the "responseId" field.

func ResponseIdIn

func ResponseIdIn(vs ...uuid.UUID) predicate.Evaluation

ResponseIdIn applies the In predicate on the "responseId" field.

func ResponseIdNEQ

func ResponseIdNEQ(v uuid.UUID) predicate.Evaluation

ResponseIdNEQ applies the NEQ predicate on the "responseId" field.

func ResponseIdNotIn

func ResponseIdNotIn(vs ...uuid.UUID) predicate.Evaluation

ResponseIdNotIn applies the NotIn predicate on the "responseId" field.

func UserId

func UserId(v uuid.UUID) predicate.Evaluation

UserId applies equality check predicate on the "userId" field. It's identical to UserIdEQ.

func UserIdEQ

func UserIdEQ(v uuid.UUID) predicate.Evaluation

UserIdEQ applies the EQ predicate on the "userId" field.

func UserIdIn

func UserIdIn(vs ...uuid.UUID) predicate.Evaluation

UserIdIn applies the In predicate on the "userId" field.

func UserIdNEQ

func UserIdNEQ(v uuid.UUID) predicate.Evaluation

UserIdNEQ applies the NEQ predicate on the "userId" field.

func UserIdNotIn

func UserIdNotIn(vs ...uuid.UUID) predicate.Evaluation

UserIdNotIn applies the NotIn predicate on the "userId" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Evaluation queries.

func ByDate

func ByDate(opts ...sql.OrderTermOption) OrderOption

ByDate orders the results by the date field.

func ByEvaluationResult

func ByEvaluationResult(opts ...sql.OrderTermOption) OrderOption

ByEvaluationResult orders the results by the evaluationResult field.

func ByExternalId

func ByExternalId(opts ...sql.OrderTermOption) OrderOption

ByExternalId orders the results by the externalId field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByResponseField

func ByResponseField(field string, opts ...sql.OrderTermOption) OrderOption

ByResponseField orders the results by response field.

func ByResponseId

func ByResponseId(opts ...sql.OrderTermOption) OrderOption

ByResponseId orders the results by the responseId field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserId

func ByUserId(opts ...sql.OrderTermOption) OrderOption

ByUserId orders the results by the userId field.

Jump to