request

package
v0.0.0-...-71ec521 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 11, 2023 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the request type in the database.
	Label = "request"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldExternalId holds the string denoting the externalid field in the database.
	FieldExternalId = "external_id"
	// FieldFrom holds the string denoting the from field in the database.
	FieldFrom = "from"
	// FieldSubject holds the string denoting the subject field in the database.
	FieldSubject = "subject"
	// FieldBody holds the string denoting the body field in the database.
	FieldBody = "body"
	// FieldDate holds the string denoting the date field in the database.
	FieldDate = "date"
	// EdgeResponses holds the string denoting the responses edge name in mutations.
	EdgeResponses = "responses"
	// Table holds the table name of the request in the database.
	Table = "requests"
	// ResponsesTable is the table that holds the responses relation/edge.
	ResponsesTable = "responses"
	// ResponsesInverseTable is the table name for the Response entity.
	// It exists in this package in order to avoid circular dependency with the "response" package.
	ResponsesInverseTable = "responses"
	// ResponsesColumn is the table column denoting the responses relation/edge.
	ResponsesColumn = "request_id"
)

Variables

Columns holds all SQL columns for request fields.

var (
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Functions

func And

func And(predicates ...predicate.Request) predicate.Request

And groups predicates with the AND operator between them.

func Body

func Body(v string) predicate.Request

Body applies equality check predicate on the "body" field. It's identical to BodyEQ.

func BodyContains

func BodyContains(v string) predicate.Request

BodyContains applies the Contains predicate on the "body" field.

func BodyContainsFold

func BodyContainsFold(v string) predicate.Request

BodyContainsFold applies the ContainsFold predicate on the "body" field.

func BodyEQ

func BodyEQ(v string) predicate.Request

BodyEQ applies the EQ predicate on the "body" field.

func BodyEqualFold

func BodyEqualFold(v string) predicate.Request

BodyEqualFold applies the EqualFold predicate on the "body" field.

func BodyGT

func BodyGT(v string) predicate.Request

BodyGT applies the GT predicate on the "body" field.

func BodyGTE

func BodyGTE(v string) predicate.Request

BodyGTE applies the GTE predicate on the "body" field.

func BodyHasPrefix

func BodyHasPrefix(v string) predicate.Request

BodyHasPrefix applies the HasPrefix predicate on the "body" field.

func BodyHasSuffix

func BodyHasSuffix(v string) predicate.Request

BodyHasSuffix applies the HasSuffix predicate on the "body" field.

func BodyIn

func BodyIn(vs ...string) predicate.Request

BodyIn applies the In predicate on the "body" field.

func BodyLT

func BodyLT(v string) predicate.Request

BodyLT applies the LT predicate on the "body" field.

func BodyLTE

func BodyLTE(v string) predicate.Request

BodyLTE applies the LTE predicate on the "body" field.

func BodyNEQ

func BodyNEQ(v string) predicate.Request

BodyNEQ applies the NEQ predicate on the "body" field.

func BodyNotIn

func BodyNotIn(vs ...string) predicate.Request

BodyNotIn applies the NotIn predicate on the "body" field.

func Date

func Date(v time.Time) predicate.Request

Date applies equality check predicate on the "date" field. It's identical to DateEQ.

func DateEQ

func DateEQ(v time.Time) predicate.Request

DateEQ applies the EQ predicate on the "date" field.

func DateGT

func DateGT(v time.Time) predicate.Request

DateGT applies the GT predicate on the "date" field.

func DateGTE

func DateGTE(v time.Time) predicate.Request

DateGTE applies the GTE predicate on the "date" field.

func DateIn

func DateIn(vs ...time.Time) predicate.Request

DateIn applies the In predicate on the "date" field.

func DateIsNil

func DateIsNil() predicate.Request

DateIsNil applies the IsNil predicate on the "date" field.

func DateLT

func DateLT(v time.Time) predicate.Request

DateLT applies the LT predicate on the "date" field.

func DateLTE

func DateLTE(v time.Time) predicate.Request

DateLTE applies the LTE predicate on the "date" field.

func DateNEQ

func DateNEQ(v time.Time) predicate.Request

DateNEQ applies the NEQ predicate on the "date" field.

func DateNotIn

func DateNotIn(vs ...time.Time) predicate.Request

DateNotIn applies the NotIn predicate on the "date" field.

func DateNotNil

func DateNotNil() predicate.Request

DateNotNil applies the NotNil predicate on the "date" field.

func ExternalId

func ExternalId(v string) predicate.Request

ExternalId applies equality check predicate on the "externalId" field. It's identical to ExternalIdEQ.

func ExternalIdContains

func ExternalIdContains(v string) predicate.Request

ExternalIdContains applies the Contains predicate on the "externalId" field.

func ExternalIdContainsFold

func ExternalIdContainsFold(v string) predicate.Request

ExternalIdContainsFold applies the ContainsFold predicate on the "externalId" field.

func ExternalIdEQ

func ExternalIdEQ(v string) predicate.Request

ExternalIdEQ applies the EQ predicate on the "externalId" field.

func ExternalIdEqualFold

func ExternalIdEqualFold(v string) predicate.Request

ExternalIdEqualFold applies the EqualFold predicate on the "externalId" field.

func ExternalIdGT

func ExternalIdGT(v string) predicate.Request

ExternalIdGT applies the GT predicate on the "externalId" field.

func ExternalIdGTE

func ExternalIdGTE(v string) predicate.Request

ExternalIdGTE applies the GTE predicate on the "externalId" field.

func ExternalIdHasPrefix

func ExternalIdHasPrefix(v string) predicate.Request

ExternalIdHasPrefix applies the HasPrefix predicate on the "externalId" field.

func ExternalIdHasSuffix

func ExternalIdHasSuffix(v string) predicate.Request

ExternalIdHasSuffix applies the HasSuffix predicate on the "externalId" field.

func ExternalIdIn

func ExternalIdIn(vs ...string) predicate.Request

ExternalIdIn applies the In predicate on the "externalId" field.

func ExternalIdIsNil

func ExternalIdIsNil() predicate.Request

ExternalIdIsNil applies the IsNil predicate on the "externalId" field.

func ExternalIdLT

func ExternalIdLT(v string) predicate.Request

ExternalIdLT applies the LT predicate on the "externalId" field.

func ExternalIdLTE

func ExternalIdLTE(v string) predicate.Request

ExternalIdLTE applies the LTE predicate on the "externalId" field.

func ExternalIdNEQ

func ExternalIdNEQ(v string) predicate.Request

ExternalIdNEQ applies the NEQ predicate on the "externalId" field.

func ExternalIdNotIn

func ExternalIdNotIn(vs ...string) predicate.Request

ExternalIdNotIn applies the NotIn predicate on the "externalId" field.

func ExternalIdNotNil

func ExternalIdNotNil() predicate.Request

ExternalIdNotNil applies the NotNil predicate on the "externalId" field.

func From

func From(v string) predicate.Request

From applies equality check predicate on the "from" field. It's identical to FromEQ.

func FromContains

func FromContains(v string) predicate.Request

FromContains applies the Contains predicate on the "from" field.

func FromContainsFold

func FromContainsFold(v string) predicate.Request

FromContainsFold applies the ContainsFold predicate on the "from" field.

func FromEQ

func FromEQ(v string) predicate.Request

FromEQ applies the EQ predicate on the "from" field.

func FromEqualFold

func FromEqualFold(v string) predicate.Request

FromEqualFold applies the EqualFold predicate on the "from" field.

func FromGT

func FromGT(v string) predicate.Request

FromGT applies the GT predicate on the "from" field.

func FromGTE

func FromGTE(v string) predicate.Request

FromGTE applies the GTE predicate on the "from" field.

func FromHasPrefix

func FromHasPrefix(v string) predicate.Request

FromHasPrefix applies the HasPrefix predicate on the "from" field.

func FromHasSuffix

func FromHasSuffix(v string) predicate.Request

FromHasSuffix applies the HasSuffix predicate on the "from" field.

func FromIn

func FromIn(vs ...string) predicate.Request

FromIn applies the In predicate on the "from" field.

func FromIsNil

func FromIsNil() predicate.Request

FromIsNil applies the IsNil predicate on the "from" field.

func FromLT

func FromLT(v string) predicate.Request

FromLT applies the LT predicate on the "from" field.

func FromLTE

func FromLTE(v string) predicate.Request

FromLTE applies the LTE predicate on the "from" field.

func FromNEQ

func FromNEQ(v string) predicate.Request

FromNEQ applies the NEQ predicate on the "from" field.

func FromNotIn

func FromNotIn(vs ...string) predicate.Request

FromNotIn applies the NotIn predicate on the "from" field.

func FromNotNil

func FromNotNil() predicate.Request

FromNotNil applies the NotNil predicate on the "from" field.

func HasResponses

func HasResponses() predicate.Request

HasResponses applies the HasEdge predicate on the "responses" edge.

func HasResponsesWith

func HasResponsesWith(preds ...predicate.Response) predicate.Request

HasResponsesWith applies the HasEdge predicate on the "responses" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Request

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Request

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Request

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Request

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Request

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Request

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Request

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Request

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Request

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Request) predicate.Request

Or groups predicates with the OR operator between them.

func Subject

func Subject(v string) predicate.Request

Subject applies equality check predicate on the "subject" field. It's identical to SubjectEQ.

func SubjectContains

func SubjectContains(v string) predicate.Request

SubjectContains applies the Contains predicate on the "subject" field.

func SubjectContainsFold

func SubjectContainsFold(v string) predicate.Request

SubjectContainsFold applies the ContainsFold predicate on the "subject" field.

func SubjectEQ

func SubjectEQ(v string) predicate.Request

SubjectEQ applies the EQ predicate on the "subject" field.

func SubjectEqualFold

func SubjectEqualFold(v string) predicate.Request

SubjectEqualFold applies the EqualFold predicate on the "subject" field.

func SubjectGT

func SubjectGT(v string) predicate.Request

SubjectGT applies the GT predicate on the "subject" field.

func SubjectGTE

func SubjectGTE(v string) predicate.Request

SubjectGTE applies the GTE predicate on the "subject" field.

func SubjectHasPrefix

func SubjectHasPrefix(v string) predicate.Request

SubjectHasPrefix applies the HasPrefix predicate on the "subject" field.

func SubjectHasSuffix

func SubjectHasSuffix(v string) predicate.Request

SubjectHasSuffix applies the HasSuffix predicate on the "subject" field.

func SubjectIn

func SubjectIn(vs ...string) predicate.Request

SubjectIn applies the In predicate on the "subject" field.

func SubjectIsNil

func SubjectIsNil() predicate.Request

SubjectIsNil applies the IsNil predicate on the "subject" field.

func SubjectLT

func SubjectLT(v string) predicate.Request

SubjectLT applies the LT predicate on the "subject" field.

func SubjectLTE

func SubjectLTE(v string) predicate.Request

SubjectLTE applies the LTE predicate on the "subject" field.

func SubjectNEQ

func SubjectNEQ(v string) predicate.Request

SubjectNEQ applies the NEQ predicate on the "subject" field.

func SubjectNotIn

func SubjectNotIn(vs ...string) predicate.Request

SubjectNotIn applies the NotIn predicate on the "subject" field.

func SubjectNotNil

func SubjectNotNil() predicate.Request

SubjectNotNil applies the NotNil predicate on the "subject" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Request queries.

func ByBody

func ByBody(opts ...sql.OrderTermOption) OrderOption

ByBody orders the results by the body field.

func ByDate

func ByDate(opts ...sql.OrderTermOption) OrderOption

ByDate orders the results by the date field.

func ByExternalId

func ByExternalId(opts ...sql.OrderTermOption) OrderOption

ByExternalId orders the results by the externalId field.

func ByFrom

func ByFrom(opts ...sql.OrderTermOption) OrderOption

ByFrom orders the results by the from field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByResponses

func ByResponses(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByResponses orders the results by responses terms.

func ByResponsesCount

func ByResponsesCount(opts ...sql.OrderTermOption) OrderOption

ByResponsesCount orders the results by responses count.

func BySubject

func BySubject(opts ...sql.OrderTermOption) OrderOption

BySubject orders the results by the subject field.

Jump to