response

package
v0.0.0-...-71ec521 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 11, 2023 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the response type in the database.
	Label = "response"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldExternalId holds the string denoting the externalid field in the database.
	FieldExternalId = "external_id"
	// FieldRequestId holds the string denoting the requestid field in the database.
	FieldRequestId = "request_id"
	// FieldScenarioId holds the string denoting the scenarioid field in the database.
	FieldScenarioId = "scenario_id"
	// FieldFrom holds the string denoting the from field in the database.
	FieldFrom = "from"
	// FieldSubject holds the string denoting the subject field in the database.
	FieldSubject = "subject"
	// FieldBody holds the string denoting the body field in the database.
	FieldBody = "body"
	// FieldDate holds the string denoting the date field in the database.
	FieldDate = "date"
	// EdgeRequest holds the string denoting the request edge name in mutations.
	EdgeRequest = "request"
	// EdgeScenario holds the string denoting the scenario edge name in mutations.
	EdgeScenario = "scenario"
	// EdgeEvaluations holds the string denoting the evaluations edge name in mutations.
	EdgeEvaluations = "evaluations"
	// Table holds the table name of the response in the database.
	Table = "responses"
	// RequestTable is the table that holds the request relation/edge.
	RequestTable = "responses"
	// RequestInverseTable is the table name for the Request entity.
	// It exists in this package in order to avoid circular dependency with the "request" package.
	RequestInverseTable = "requests"
	// RequestColumn is the table column denoting the request relation/edge.
	RequestColumn = "request_id"
	// ScenarioTable is the table that holds the scenario relation/edge.
	ScenarioTable = "responses"
	// ScenarioInverseTable is the table name for the Scenario entity.
	// It exists in this package in order to avoid circular dependency with the "scenario" package.
	ScenarioInverseTable = "scenarios"
	// ScenarioColumn is the table column denoting the scenario relation/edge.
	ScenarioColumn = "scenario_id"
	// EvaluationsTable is the table that holds the evaluations relation/edge.
	EvaluationsTable = "evaluations"
	// EvaluationsInverseTable is the table name for the Evaluation entity.
	// It exists in this package in order to avoid circular dependency with the "evaluation" package.
	EvaluationsInverseTable = "evaluations"
	// EvaluationsColumn is the table column denoting the evaluations relation/edge.
	EvaluationsColumn = "response_id"
)

Variables

Columns holds all SQL columns for response fields.

var (
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Functions

func And

func And(predicates ...predicate.Response) predicate.Response

And groups predicates with the AND operator between them.

func Body

func Body(v string) predicate.Response

Body applies equality check predicate on the "body" field. It's identical to BodyEQ.

func BodyContains

func BodyContains(v string) predicate.Response

BodyContains applies the Contains predicate on the "body" field.

func BodyContainsFold

func BodyContainsFold(v string) predicate.Response

BodyContainsFold applies the ContainsFold predicate on the "body" field.

func BodyEQ

func BodyEQ(v string) predicate.Response

BodyEQ applies the EQ predicate on the "body" field.

func BodyEqualFold

func BodyEqualFold(v string) predicate.Response

BodyEqualFold applies the EqualFold predicate on the "body" field.

func BodyGT

func BodyGT(v string) predicate.Response

BodyGT applies the GT predicate on the "body" field.

func BodyGTE

func BodyGTE(v string) predicate.Response

BodyGTE applies the GTE predicate on the "body" field.

func BodyHasPrefix

func BodyHasPrefix(v string) predicate.Response

BodyHasPrefix applies the HasPrefix predicate on the "body" field.

func BodyHasSuffix

func BodyHasSuffix(v string) predicate.Response

BodyHasSuffix applies the HasSuffix predicate on the "body" field.

func BodyIn

func BodyIn(vs ...string) predicate.Response

BodyIn applies the In predicate on the "body" field.

func BodyLT

func BodyLT(v string) predicate.Response

BodyLT applies the LT predicate on the "body" field.

func BodyLTE

func BodyLTE(v string) predicate.Response

BodyLTE applies the LTE predicate on the "body" field.

func BodyNEQ

func BodyNEQ(v string) predicate.Response

BodyNEQ applies the NEQ predicate on the "body" field.

func BodyNotIn

func BodyNotIn(vs ...string) predicate.Response

BodyNotIn applies the NotIn predicate on the "body" field.

func Date

func Date(v time.Time) predicate.Response

Date applies equality check predicate on the "date" field. It's identical to DateEQ.

func DateEQ

func DateEQ(v time.Time) predicate.Response

DateEQ applies the EQ predicate on the "date" field.

func DateGT

func DateGT(v time.Time) predicate.Response

DateGT applies the GT predicate on the "date" field.

func DateGTE

func DateGTE(v time.Time) predicate.Response

DateGTE applies the GTE predicate on the "date" field.

func DateIn

func DateIn(vs ...time.Time) predicate.Response

DateIn applies the In predicate on the "date" field.

func DateIsNil

func DateIsNil() predicate.Response

DateIsNil applies the IsNil predicate on the "date" field.

func DateLT

func DateLT(v time.Time) predicate.Response

DateLT applies the LT predicate on the "date" field.

func DateLTE

func DateLTE(v time.Time) predicate.Response

DateLTE applies the LTE predicate on the "date" field.

func DateNEQ

func DateNEQ(v time.Time) predicate.Response

DateNEQ applies the NEQ predicate on the "date" field.

func DateNotIn

func DateNotIn(vs ...time.Time) predicate.Response

DateNotIn applies the NotIn predicate on the "date" field.

func DateNotNil

func DateNotNil() predicate.Response

DateNotNil applies the NotNil predicate on the "date" field.

func ExternalId

func ExternalId(v string) predicate.Response

ExternalId applies equality check predicate on the "externalId" field. It's identical to ExternalIdEQ.

func ExternalIdContains

func ExternalIdContains(v string) predicate.Response

ExternalIdContains applies the Contains predicate on the "externalId" field.

func ExternalIdContainsFold

func ExternalIdContainsFold(v string) predicate.Response

ExternalIdContainsFold applies the ContainsFold predicate on the "externalId" field.

func ExternalIdEQ

func ExternalIdEQ(v string) predicate.Response

ExternalIdEQ applies the EQ predicate on the "externalId" field.

func ExternalIdEqualFold

func ExternalIdEqualFold(v string) predicate.Response

ExternalIdEqualFold applies the EqualFold predicate on the "externalId" field.

func ExternalIdGT

func ExternalIdGT(v string) predicate.Response

ExternalIdGT applies the GT predicate on the "externalId" field.

func ExternalIdGTE

func ExternalIdGTE(v string) predicate.Response

ExternalIdGTE applies the GTE predicate on the "externalId" field.

func ExternalIdHasPrefix

func ExternalIdHasPrefix(v string) predicate.Response

ExternalIdHasPrefix applies the HasPrefix predicate on the "externalId" field.

func ExternalIdHasSuffix

func ExternalIdHasSuffix(v string) predicate.Response

ExternalIdHasSuffix applies the HasSuffix predicate on the "externalId" field.

func ExternalIdIn

func ExternalIdIn(vs ...string) predicate.Response

ExternalIdIn applies the In predicate on the "externalId" field.

func ExternalIdIsNil

func ExternalIdIsNil() predicate.Response

ExternalIdIsNil applies the IsNil predicate on the "externalId" field.

func ExternalIdLT

func ExternalIdLT(v string) predicate.Response

ExternalIdLT applies the LT predicate on the "externalId" field.

func ExternalIdLTE

func ExternalIdLTE(v string) predicate.Response

ExternalIdLTE applies the LTE predicate on the "externalId" field.

func ExternalIdNEQ

func ExternalIdNEQ(v string) predicate.Response

ExternalIdNEQ applies the NEQ predicate on the "externalId" field.

func ExternalIdNotIn

func ExternalIdNotIn(vs ...string) predicate.Response

ExternalIdNotIn applies the NotIn predicate on the "externalId" field.

func ExternalIdNotNil

func ExternalIdNotNil() predicate.Response

ExternalIdNotNil applies the NotNil predicate on the "externalId" field.

func From

func From(v string) predicate.Response

From applies equality check predicate on the "from" field. It's identical to FromEQ.

func FromContains

func FromContains(v string) predicate.Response

FromContains applies the Contains predicate on the "from" field.

func FromContainsFold

func FromContainsFold(v string) predicate.Response

FromContainsFold applies the ContainsFold predicate on the "from" field.

func FromEQ

func FromEQ(v string) predicate.Response

FromEQ applies the EQ predicate on the "from" field.

func FromEqualFold

func FromEqualFold(v string) predicate.Response

FromEqualFold applies the EqualFold predicate on the "from" field.

func FromGT

func FromGT(v string) predicate.Response

FromGT applies the GT predicate on the "from" field.

func FromGTE

func FromGTE(v string) predicate.Response

FromGTE applies the GTE predicate on the "from" field.

func FromHasPrefix

func FromHasPrefix(v string) predicate.Response

FromHasPrefix applies the HasPrefix predicate on the "from" field.

func FromHasSuffix

func FromHasSuffix(v string) predicate.Response

FromHasSuffix applies the HasSuffix predicate on the "from" field.

func FromIn

func FromIn(vs ...string) predicate.Response

FromIn applies the In predicate on the "from" field.

func FromIsNil

func FromIsNil() predicate.Response

FromIsNil applies the IsNil predicate on the "from" field.

func FromLT

func FromLT(v string) predicate.Response

FromLT applies the LT predicate on the "from" field.

func FromLTE

func FromLTE(v string) predicate.Response

FromLTE applies the LTE predicate on the "from" field.

func FromNEQ

func FromNEQ(v string) predicate.Response

FromNEQ applies the NEQ predicate on the "from" field.

func FromNotIn

func FromNotIn(vs ...string) predicate.Response

FromNotIn applies the NotIn predicate on the "from" field.

func FromNotNil

func FromNotNil() predicate.Response

FromNotNil applies the NotNil predicate on the "from" field.

func HasEvaluations

func HasEvaluations() predicate.Response

HasEvaluations applies the HasEdge predicate on the "evaluations" edge.

func HasEvaluationsWith

func HasEvaluationsWith(preds ...predicate.Evaluation) predicate.Response

HasEvaluationsWith applies the HasEdge predicate on the "evaluations" edge with a given conditions (other predicates).

func HasRequest

func HasRequest() predicate.Response

HasRequest applies the HasEdge predicate on the "request" edge.

func HasRequestWith

func HasRequestWith(preds ...predicate.Request) predicate.Response

HasRequestWith applies the HasEdge predicate on the "request" edge with a given conditions (other predicates).

func HasScenario

func HasScenario() predicate.Response

HasScenario applies the HasEdge predicate on the "scenario" edge.

func HasScenarioWith

func HasScenarioWith(preds ...predicate.Scenario) predicate.Response

HasScenarioWith applies the HasEdge predicate on the "scenario" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.Response

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Response

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Response

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Response

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Response

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Response

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Response

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Response

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Response

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Response) predicate.Response

Or groups predicates with the OR operator between them.

func RequestId

func RequestId(v uuid.UUID) predicate.Response

RequestId applies equality check predicate on the "requestId" field. It's identical to RequestIdEQ.

func RequestIdEQ

func RequestIdEQ(v uuid.UUID) predicate.Response

RequestIdEQ applies the EQ predicate on the "requestId" field.

func RequestIdIn

func RequestIdIn(vs ...uuid.UUID) predicate.Response

RequestIdIn applies the In predicate on the "requestId" field.

func RequestIdNEQ

func RequestIdNEQ(v uuid.UUID) predicate.Response

RequestIdNEQ applies the NEQ predicate on the "requestId" field.

func RequestIdNotIn

func RequestIdNotIn(vs ...uuid.UUID) predicate.Response

RequestIdNotIn applies the NotIn predicate on the "requestId" field.

func ScenarioId

func ScenarioId(v uuid.UUID) predicate.Response

ScenarioId applies equality check predicate on the "scenarioId" field. It's identical to ScenarioIdEQ.

func ScenarioIdEQ

func ScenarioIdEQ(v uuid.UUID) predicate.Response

ScenarioIdEQ applies the EQ predicate on the "scenarioId" field.

func ScenarioIdIn

func ScenarioIdIn(vs ...uuid.UUID) predicate.Response

ScenarioIdIn applies the In predicate on the "scenarioId" field.

func ScenarioIdNEQ

func ScenarioIdNEQ(v uuid.UUID) predicate.Response

ScenarioIdNEQ applies the NEQ predicate on the "scenarioId" field.

func ScenarioIdNotIn

func ScenarioIdNotIn(vs ...uuid.UUID) predicate.Response

ScenarioIdNotIn applies the NotIn predicate on the "scenarioId" field.

func Subject

func Subject(v string) predicate.Response

Subject applies equality check predicate on the "subject" field. It's identical to SubjectEQ.

func SubjectContains

func SubjectContains(v string) predicate.Response

SubjectContains applies the Contains predicate on the "subject" field.

func SubjectContainsFold

func SubjectContainsFold(v string) predicate.Response

SubjectContainsFold applies the ContainsFold predicate on the "subject" field.

func SubjectEQ

func SubjectEQ(v string) predicate.Response

SubjectEQ applies the EQ predicate on the "subject" field.

func SubjectEqualFold

func SubjectEqualFold(v string) predicate.Response

SubjectEqualFold applies the EqualFold predicate on the "subject" field.

func SubjectGT

func SubjectGT(v string) predicate.Response

SubjectGT applies the GT predicate on the "subject" field.

func SubjectGTE

func SubjectGTE(v string) predicate.Response

SubjectGTE applies the GTE predicate on the "subject" field.

func SubjectHasPrefix

func SubjectHasPrefix(v string) predicate.Response

SubjectHasPrefix applies the HasPrefix predicate on the "subject" field.

func SubjectHasSuffix

func SubjectHasSuffix(v string) predicate.Response

SubjectHasSuffix applies the HasSuffix predicate on the "subject" field.

func SubjectIn

func SubjectIn(vs ...string) predicate.Response

SubjectIn applies the In predicate on the "subject" field.

func SubjectIsNil

func SubjectIsNil() predicate.Response

SubjectIsNil applies the IsNil predicate on the "subject" field.

func SubjectLT

func SubjectLT(v string) predicate.Response

SubjectLT applies the LT predicate on the "subject" field.

func SubjectLTE

func SubjectLTE(v string) predicate.Response

SubjectLTE applies the LTE predicate on the "subject" field.

func SubjectNEQ

func SubjectNEQ(v string) predicate.Response

SubjectNEQ applies the NEQ predicate on the "subject" field.

func SubjectNotIn

func SubjectNotIn(vs ...string) predicate.Response

SubjectNotIn applies the NotIn predicate on the "subject" field.

func SubjectNotNil

func SubjectNotNil() predicate.Response

SubjectNotNil applies the NotNil predicate on the "subject" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Response queries.

func ByBody

func ByBody(opts ...sql.OrderTermOption) OrderOption

ByBody orders the results by the body field.

func ByDate

func ByDate(opts ...sql.OrderTermOption) OrderOption

ByDate orders the results by the date field.

func ByEvaluations

func ByEvaluations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEvaluations orders the results by evaluations terms.

func ByEvaluationsCount

func ByEvaluationsCount(opts ...sql.OrderTermOption) OrderOption

ByEvaluationsCount orders the results by evaluations count.

func ByExternalId

func ByExternalId(opts ...sql.OrderTermOption) OrderOption

ByExternalId orders the results by the externalId field.

func ByFrom

func ByFrom(opts ...sql.OrderTermOption) OrderOption

ByFrom orders the results by the from field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByRequestField

func ByRequestField(field string, opts ...sql.OrderTermOption) OrderOption

ByRequestField orders the results by request field.

func ByRequestId

func ByRequestId(opts ...sql.OrderTermOption) OrderOption

ByRequestId orders the results by the requestId field.

func ByScenarioField

func ByScenarioField(field string, opts ...sql.OrderTermOption) OrderOption

ByScenarioField orders the results by scenario field.

func ByScenarioId

func ByScenarioId(opts ...sql.OrderTermOption) OrderOption

ByScenarioId orders the results by the scenarioId field.

func BySubject

func BySubject(opts ...sql.OrderTermOption) OrderOption

BySubject orders the results by the subject field.

Jump to