user

package
v0.0.0-...-71ec521 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 11, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the user type in the database.
	Label = "user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldExternalId holds the string denoting the externalid field in the database.
	FieldExternalId = "external_id"
	// FieldType holds the string denoting the type field in the database.
	FieldType = "type"
	// EdgeEvaluations holds the string denoting the evaluations edge name in mutations.
	EdgeEvaluations = "evaluations"
	// Table holds the table name of the user in the database.
	Table = "users"
	// EvaluationsTable is the table that holds the evaluations relation/edge.
	EvaluationsTable = "evaluations"
	// EvaluationsInverseTable is the table name for the Evaluation entity.
	// It exists in this package in order to avoid circular dependency with the "evaluation" package.
	EvaluationsInverseTable = "evaluations"
	// EvaluationsColumn is the table column denoting the evaluations relation/edge.
	EvaluationsColumn = "user_id"
)

Variables

var (
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// ExternalIdValidator is a validator for the "externalId" field. It is called by the builders before save.
	ExternalIdValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for user fields.

Functions

func And

func And(predicates ...predicate.User) predicate.User

And groups predicates with the AND operator between them.

func ExternalId

func ExternalId(v string) predicate.User

ExternalId applies equality check predicate on the "externalId" field. It's identical to ExternalIdEQ.

func ExternalIdContains

func ExternalIdContains(v string) predicate.User

ExternalIdContains applies the Contains predicate on the "externalId" field.

func ExternalIdContainsFold

func ExternalIdContainsFold(v string) predicate.User

ExternalIdContainsFold applies the ContainsFold predicate on the "externalId" field.

func ExternalIdEQ

func ExternalIdEQ(v string) predicate.User

ExternalIdEQ applies the EQ predicate on the "externalId" field.

func ExternalIdEqualFold

func ExternalIdEqualFold(v string) predicate.User

ExternalIdEqualFold applies the EqualFold predicate on the "externalId" field.

func ExternalIdGT

func ExternalIdGT(v string) predicate.User

ExternalIdGT applies the GT predicate on the "externalId" field.

func ExternalIdGTE

func ExternalIdGTE(v string) predicate.User

ExternalIdGTE applies the GTE predicate on the "externalId" field.

func ExternalIdHasPrefix

func ExternalIdHasPrefix(v string) predicate.User

ExternalIdHasPrefix applies the HasPrefix predicate on the "externalId" field.

func ExternalIdHasSuffix

func ExternalIdHasSuffix(v string) predicate.User

ExternalIdHasSuffix applies the HasSuffix predicate on the "externalId" field.

func ExternalIdIn

func ExternalIdIn(vs ...string) predicate.User

ExternalIdIn applies the In predicate on the "externalId" field.

func ExternalIdLT

func ExternalIdLT(v string) predicate.User

ExternalIdLT applies the LT predicate on the "externalId" field.

func ExternalIdLTE

func ExternalIdLTE(v string) predicate.User

ExternalIdLTE applies the LTE predicate on the "externalId" field.

func ExternalIdNEQ

func ExternalIdNEQ(v string) predicate.User

ExternalIdNEQ applies the NEQ predicate on the "externalId" field.

func ExternalIdNotIn

func ExternalIdNotIn(vs ...string) predicate.User

ExternalIdNotIn applies the NotIn predicate on the "externalId" field.

func HasEvaluations

func HasEvaluations() predicate.User

HasEvaluations applies the HasEdge predicate on the "evaluations" edge.

func HasEvaluationsWith

func HasEvaluationsWith(preds ...predicate.Evaluation) predicate.User

HasEvaluationsWith applies the HasEdge predicate on the "evaluations" edge with a given conditions (other predicates).

func ID

func ID(id uuid.UUID) predicate.User

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.User

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.User

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.User

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.User

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.User

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.User

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.User

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.User

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.User

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.User

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.User

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.User

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.User

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.User

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.User

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.User) predicate.User

Or groups predicates with the OR operator between them.

func Type

func Type(v string) predicate.User

Type applies equality check predicate on the "type" field. It's identical to TypeEQ.

func TypeContains

func TypeContains(v string) predicate.User

TypeContains applies the Contains predicate on the "type" field.

func TypeContainsFold

func TypeContainsFold(v string) predicate.User

TypeContainsFold applies the ContainsFold predicate on the "type" field.

func TypeEQ

func TypeEQ(v string) predicate.User

TypeEQ applies the EQ predicate on the "type" field.

func TypeEqualFold

func TypeEqualFold(v string) predicate.User

TypeEqualFold applies the EqualFold predicate on the "type" field.

func TypeGT

func TypeGT(v string) predicate.User

TypeGT applies the GT predicate on the "type" field.

func TypeGTE

func TypeGTE(v string) predicate.User

TypeGTE applies the GTE predicate on the "type" field.

func TypeHasPrefix

func TypeHasPrefix(v string) predicate.User

TypeHasPrefix applies the HasPrefix predicate on the "type" field.

func TypeHasSuffix

func TypeHasSuffix(v string) predicate.User

TypeHasSuffix applies the HasSuffix predicate on the "type" field.

func TypeIn

func TypeIn(vs ...string) predicate.User

TypeIn applies the In predicate on the "type" field.

func TypeIsNil

func TypeIsNil() predicate.User

TypeIsNil applies the IsNil predicate on the "type" field.

func TypeLT

func TypeLT(v string) predicate.User

TypeLT applies the LT predicate on the "type" field.

func TypeLTE

func TypeLTE(v string) predicate.User

TypeLTE applies the LTE predicate on the "type" field.

func TypeNEQ

func TypeNEQ(v string) predicate.User

TypeNEQ applies the NEQ predicate on the "type" field.

func TypeNotIn

func TypeNotIn(vs ...string) predicate.User

TypeNotIn applies the NotIn predicate on the "type" field.

func TypeNotNil

func TypeNotNil() predicate.User

TypeNotNil applies the NotNil predicate on the "type" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the User queries.

func ByEvaluations

func ByEvaluations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByEvaluations orders the results by evaluations terms.

func ByEvaluationsCount

func ByEvaluationsCount(opts ...sql.OrderTermOption) OrderOption

ByEvaluationsCount orders the results by evaluations count.

func ByExternalId

func ByExternalId(opts ...sql.OrderTermOption) OrderOption

ByExternalId orders the results by the externalId field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByType

func ByType(opts ...sql.OrderTermOption) OrderOption

ByType orders the results by the type field.

Jump to