Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Request) predicate.Request
- func Body(v string) predicate.Request
- func BodyContains(v string) predicate.Request
- func BodyContainsFold(v string) predicate.Request
- func BodyEQ(v string) predicate.Request
- func BodyEqualFold(v string) predicate.Request
- func BodyGT(v string) predicate.Request
- func BodyGTE(v string) predicate.Request
- func BodyHasPrefix(v string) predicate.Request
- func BodyHasSuffix(v string) predicate.Request
- func BodyIn(vs ...string) predicate.Request
- func BodyLT(v string) predicate.Request
- func BodyLTE(v string) predicate.Request
- func BodyNEQ(v string) predicate.Request
- func BodyNotIn(vs ...string) predicate.Request
- func Date(v time.Time) predicate.Request
- func DateEQ(v time.Time) predicate.Request
- func DateGT(v time.Time) predicate.Request
- func DateGTE(v time.Time) predicate.Request
- func DateIn(vs ...time.Time) predicate.Request
- func DateIsNil() predicate.Request
- func DateLT(v time.Time) predicate.Request
- func DateLTE(v time.Time) predicate.Request
- func DateNEQ(v time.Time) predicate.Request
- func DateNotIn(vs ...time.Time) predicate.Request
- func DateNotNil() predicate.Request
- func ExternalId(v string) predicate.Request
- func ExternalIdContains(v string) predicate.Request
- func ExternalIdContainsFold(v string) predicate.Request
- func ExternalIdEQ(v string) predicate.Request
- func ExternalIdEqualFold(v string) predicate.Request
- func ExternalIdGT(v string) predicate.Request
- func ExternalIdGTE(v string) predicate.Request
- func ExternalIdHasPrefix(v string) predicate.Request
- func ExternalIdHasSuffix(v string) predicate.Request
- func ExternalIdIn(vs ...string) predicate.Request
- func ExternalIdIsNil() predicate.Request
- func ExternalIdLT(v string) predicate.Request
- func ExternalIdLTE(v string) predicate.Request
- func ExternalIdNEQ(v string) predicate.Request
- func ExternalIdNotIn(vs ...string) predicate.Request
- func ExternalIdNotNil() predicate.Request
- func From(v string) predicate.Request
- func FromContains(v string) predicate.Request
- func FromContainsFold(v string) predicate.Request
- func FromEQ(v string) predicate.Request
- func FromEqualFold(v string) predicate.Request
- func FromGT(v string) predicate.Request
- func FromGTE(v string) predicate.Request
- func FromHasPrefix(v string) predicate.Request
- func FromHasSuffix(v string) predicate.Request
- func FromIn(vs ...string) predicate.Request
- func FromIsNil() predicate.Request
- func FromLT(v string) predicate.Request
- func FromLTE(v string) predicate.Request
- func FromNEQ(v string) predicate.Request
- func FromNotIn(vs ...string) predicate.Request
- func FromNotNil() predicate.Request
- func HasResponses() predicate.Request
- func HasResponsesWith(preds ...predicate.Response) predicate.Request
- func ID(id uuid.UUID) predicate.Request
- func IDEQ(id uuid.UUID) predicate.Request
- func IDGT(id uuid.UUID) predicate.Request
- func IDGTE(id uuid.UUID) predicate.Request
- func IDIn(ids ...uuid.UUID) predicate.Request
- func IDLT(id uuid.UUID) predicate.Request
- func IDLTE(id uuid.UUID) predicate.Request
- func IDNEQ(id uuid.UUID) predicate.Request
- func IDNotIn(ids ...uuid.UUID) predicate.Request
- func Not(p predicate.Request) predicate.Request
- func Or(predicates ...predicate.Request) predicate.Request
- func Subject(v string) predicate.Request
- func SubjectContains(v string) predicate.Request
- func SubjectContainsFold(v string) predicate.Request
- func SubjectEQ(v string) predicate.Request
- func SubjectEqualFold(v string) predicate.Request
- func SubjectGT(v string) predicate.Request
- func SubjectGTE(v string) predicate.Request
- func SubjectHasPrefix(v string) predicate.Request
- func SubjectHasSuffix(v string) predicate.Request
- func SubjectIn(vs ...string) predicate.Request
- func SubjectIsNil() predicate.Request
- func SubjectLT(v string) predicate.Request
- func SubjectLTE(v string) predicate.Request
- func SubjectNEQ(v string) predicate.Request
- func SubjectNotIn(vs ...string) predicate.Request
- func SubjectNotNil() predicate.Request
- func ValidColumn(column string) bool
- type OrderOption
- func ByBody(opts ...sql.OrderTermOption) OrderOption
- func ByDate(opts ...sql.OrderTermOption) OrderOption
- func ByExternalId(opts ...sql.OrderTermOption) OrderOption
- func ByFrom(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByResponses(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByResponsesCount(opts ...sql.OrderTermOption) OrderOption
- func BySubject(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the request type in the database. Label = "request" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldExternalId holds the string denoting the externalid field in the database. FieldExternalId = "external_id" // FieldFrom holds the string denoting the from field in the database. FieldFrom = "from" // FieldSubject holds the string denoting the subject field in the database. FieldSubject = "subject" // FieldBody holds the string denoting the body field in the database. FieldBody = "body" // FieldDate holds the string denoting the date field in the database. FieldDate = "date" // EdgeResponses holds the string denoting the responses edge name in mutations. EdgeResponses = "responses" // Table holds the table name of the request in the database. Table = "requests" // ResponsesTable is the table that holds the responses relation/edge. ResponsesTable = "responses" // ResponsesInverseTable is the table name for the Response entity. // It exists in this package in order to avoid circular dependency with the "response" package. ResponsesInverseTable = "responses" // ResponsesColumn is the table column denoting the responses relation/edge. ResponsesColumn = "request_id" )
Variables ¶
var Columns = []string{ FieldID, FieldExternalId, FieldFrom, FieldSubject, FieldBody, FieldDate, }
Columns holds all SQL columns for request fields.
var ( // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
Functions ¶
func BodyContains ¶
BodyContains applies the Contains predicate on the "body" field.
func BodyContainsFold ¶
BodyContainsFold applies the ContainsFold predicate on the "body" field.
func BodyEqualFold ¶
BodyEqualFold applies the EqualFold predicate on the "body" field.
func BodyHasPrefix ¶
BodyHasPrefix applies the HasPrefix predicate on the "body" field.
func BodyHasSuffix ¶
BodyHasSuffix applies the HasSuffix predicate on the "body" field.
func DateNotNil ¶
DateNotNil applies the NotNil predicate on the "date" field.
func ExternalId ¶
ExternalId applies equality check predicate on the "externalId" field. It's identical to ExternalIdEQ.
func ExternalIdContains ¶
ExternalIdContains applies the Contains predicate on the "externalId" field.
func ExternalIdContainsFold ¶
ExternalIdContainsFold applies the ContainsFold predicate on the "externalId" field.
func ExternalIdEQ ¶
ExternalIdEQ applies the EQ predicate on the "externalId" field.
func ExternalIdEqualFold ¶
ExternalIdEqualFold applies the EqualFold predicate on the "externalId" field.
func ExternalIdGT ¶
ExternalIdGT applies the GT predicate on the "externalId" field.
func ExternalIdGTE ¶
ExternalIdGTE applies the GTE predicate on the "externalId" field.
func ExternalIdHasPrefix ¶
ExternalIdHasPrefix applies the HasPrefix predicate on the "externalId" field.
func ExternalIdHasSuffix ¶
ExternalIdHasSuffix applies the HasSuffix predicate on the "externalId" field.
func ExternalIdIn ¶
ExternalIdIn applies the In predicate on the "externalId" field.
func ExternalIdIsNil ¶
ExternalIdIsNil applies the IsNil predicate on the "externalId" field.
func ExternalIdLT ¶
ExternalIdLT applies the LT predicate on the "externalId" field.
func ExternalIdLTE ¶
ExternalIdLTE applies the LTE predicate on the "externalId" field.
func ExternalIdNEQ ¶
ExternalIdNEQ applies the NEQ predicate on the "externalId" field.
func ExternalIdNotIn ¶
ExternalIdNotIn applies the NotIn predicate on the "externalId" field.
func ExternalIdNotNil ¶
ExternalIdNotNil applies the NotNil predicate on the "externalId" field.
func FromContains ¶
FromContains applies the Contains predicate on the "from" field.
func FromContainsFold ¶
FromContainsFold applies the ContainsFold predicate on the "from" field.
func FromEqualFold ¶
FromEqualFold applies the EqualFold predicate on the "from" field.
func FromHasPrefix ¶
FromHasPrefix applies the HasPrefix predicate on the "from" field.
func FromHasSuffix ¶
FromHasSuffix applies the HasSuffix predicate on the "from" field.
func FromNotNil ¶
FromNotNil applies the NotNil predicate on the "from" field.
func HasResponses ¶
HasResponses applies the HasEdge predicate on the "responses" edge.
func HasResponsesWith ¶
HasResponsesWith applies the HasEdge predicate on the "responses" edge with a given conditions (other predicates).
func Subject ¶
Subject applies equality check predicate on the "subject" field. It's identical to SubjectEQ.
func SubjectContains ¶
SubjectContains applies the Contains predicate on the "subject" field.
func SubjectContainsFold ¶
SubjectContainsFold applies the ContainsFold predicate on the "subject" field.
func SubjectEqualFold ¶
SubjectEqualFold applies the EqualFold predicate on the "subject" field.
func SubjectGTE ¶
SubjectGTE applies the GTE predicate on the "subject" field.
func SubjectHasPrefix ¶
SubjectHasPrefix applies the HasPrefix predicate on the "subject" field.
func SubjectHasSuffix ¶
SubjectHasSuffix applies the HasSuffix predicate on the "subject" field.
func SubjectIsNil ¶
SubjectIsNil applies the IsNil predicate on the "subject" field.
func SubjectLTE ¶
SubjectLTE applies the LTE predicate on the "subject" field.
func SubjectNEQ ¶
SubjectNEQ applies the NEQ predicate on the "subject" field.
func SubjectNotIn ¶
SubjectNotIn applies the NotIn predicate on the "subject" field.
func SubjectNotNil ¶
SubjectNotNil applies the NotNil predicate on the "subject" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Request queries.
func ByBody ¶
func ByBody(opts ...sql.OrderTermOption) OrderOption
ByBody orders the results by the body field.
func ByDate ¶
func ByDate(opts ...sql.OrderTermOption) OrderOption
ByDate orders the results by the date field.
func ByExternalId ¶
func ByExternalId(opts ...sql.OrderTermOption) OrderOption
ByExternalId orders the results by the externalId field.
func ByFrom ¶
func ByFrom(opts ...sql.OrderTermOption) OrderOption
ByFrom orders the results by the from field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByResponses ¶
func ByResponses(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByResponses orders the results by responses terms.
func ByResponsesCount ¶
func ByResponsesCount(opts ...sql.OrderTermOption) OrderOption
ByResponsesCount orders the results by responses count.
func BySubject ¶
func BySubject(opts ...sql.OrderTermOption) OrderOption
BySubject orders the results by the subject field.