Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Response) predicate.Response
- func Body(v string) predicate.Response
- func BodyContains(v string) predicate.Response
- func BodyContainsFold(v string) predicate.Response
- func BodyEQ(v string) predicate.Response
- func BodyEqualFold(v string) predicate.Response
- func BodyGT(v string) predicate.Response
- func BodyGTE(v string) predicate.Response
- func BodyHasPrefix(v string) predicate.Response
- func BodyHasSuffix(v string) predicate.Response
- func BodyIn(vs ...string) predicate.Response
- func BodyLT(v string) predicate.Response
- func BodyLTE(v string) predicate.Response
- func BodyNEQ(v string) predicate.Response
- func BodyNotIn(vs ...string) predicate.Response
- func Date(v time.Time) predicate.Response
- func DateEQ(v time.Time) predicate.Response
- func DateGT(v time.Time) predicate.Response
- func DateGTE(v time.Time) predicate.Response
- func DateIn(vs ...time.Time) predicate.Response
- func DateIsNil() predicate.Response
- func DateLT(v time.Time) predicate.Response
- func DateLTE(v time.Time) predicate.Response
- func DateNEQ(v time.Time) predicate.Response
- func DateNotIn(vs ...time.Time) predicate.Response
- func DateNotNil() predicate.Response
- func ExternalId(v string) predicate.Response
- func ExternalIdContains(v string) predicate.Response
- func ExternalIdContainsFold(v string) predicate.Response
- func ExternalIdEQ(v string) predicate.Response
- func ExternalIdEqualFold(v string) predicate.Response
- func ExternalIdGT(v string) predicate.Response
- func ExternalIdGTE(v string) predicate.Response
- func ExternalIdHasPrefix(v string) predicate.Response
- func ExternalIdHasSuffix(v string) predicate.Response
- func ExternalIdIn(vs ...string) predicate.Response
- func ExternalIdIsNil() predicate.Response
- func ExternalIdLT(v string) predicate.Response
- func ExternalIdLTE(v string) predicate.Response
- func ExternalIdNEQ(v string) predicate.Response
- func ExternalIdNotIn(vs ...string) predicate.Response
- func ExternalIdNotNil() predicate.Response
- func From(v string) predicate.Response
- func FromContains(v string) predicate.Response
- func FromContainsFold(v string) predicate.Response
- func FromEQ(v string) predicate.Response
- func FromEqualFold(v string) predicate.Response
- func FromGT(v string) predicate.Response
- func FromGTE(v string) predicate.Response
- func FromHasPrefix(v string) predicate.Response
- func FromHasSuffix(v string) predicate.Response
- func FromIn(vs ...string) predicate.Response
- func FromIsNil() predicate.Response
- func FromLT(v string) predicate.Response
- func FromLTE(v string) predicate.Response
- func FromNEQ(v string) predicate.Response
- func FromNotIn(vs ...string) predicate.Response
- func FromNotNil() predicate.Response
- func HasEvaluations() predicate.Response
- func HasEvaluationsWith(preds ...predicate.Evaluation) predicate.Response
- func HasRequest() predicate.Response
- func HasRequestWith(preds ...predicate.Request) predicate.Response
- func HasScenario() predicate.Response
- func HasScenarioWith(preds ...predicate.Scenario) predicate.Response
- func ID(id uuid.UUID) predicate.Response
- func IDEQ(id uuid.UUID) predicate.Response
- func IDGT(id uuid.UUID) predicate.Response
- func IDGTE(id uuid.UUID) predicate.Response
- func IDIn(ids ...uuid.UUID) predicate.Response
- func IDLT(id uuid.UUID) predicate.Response
- func IDLTE(id uuid.UUID) predicate.Response
- func IDNEQ(id uuid.UUID) predicate.Response
- func IDNotIn(ids ...uuid.UUID) predicate.Response
- func Not(p predicate.Response) predicate.Response
- func Or(predicates ...predicate.Response) predicate.Response
- func RequestId(v uuid.UUID) predicate.Response
- func RequestIdEQ(v uuid.UUID) predicate.Response
- func RequestIdIn(vs ...uuid.UUID) predicate.Response
- func RequestIdNEQ(v uuid.UUID) predicate.Response
- func RequestIdNotIn(vs ...uuid.UUID) predicate.Response
- func ScenarioId(v uuid.UUID) predicate.Response
- func ScenarioIdEQ(v uuid.UUID) predicate.Response
- func ScenarioIdIn(vs ...uuid.UUID) predicate.Response
- func ScenarioIdNEQ(v uuid.UUID) predicate.Response
- func ScenarioIdNotIn(vs ...uuid.UUID) predicate.Response
- func Subject(v string) predicate.Response
- func SubjectContains(v string) predicate.Response
- func SubjectContainsFold(v string) predicate.Response
- func SubjectEQ(v string) predicate.Response
- func SubjectEqualFold(v string) predicate.Response
- func SubjectGT(v string) predicate.Response
- func SubjectGTE(v string) predicate.Response
- func SubjectHasPrefix(v string) predicate.Response
- func SubjectHasSuffix(v string) predicate.Response
- func SubjectIn(vs ...string) predicate.Response
- func SubjectIsNil() predicate.Response
- func SubjectLT(v string) predicate.Response
- func SubjectLTE(v string) predicate.Response
- func SubjectNEQ(v string) predicate.Response
- func SubjectNotIn(vs ...string) predicate.Response
- func SubjectNotNil() predicate.Response
- func ValidColumn(column string) bool
- type OrderOption
- func ByBody(opts ...sql.OrderTermOption) OrderOption
- func ByDate(opts ...sql.OrderTermOption) OrderOption
- func ByEvaluations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEvaluationsCount(opts ...sql.OrderTermOption) OrderOption
- func ByExternalId(opts ...sql.OrderTermOption) OrderOption
- func ByFrom(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByRequestField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByRequestId(opts ...sql.OrderTermOption) OrderOption
- func ByScenarioField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByScenarioId(opts ...sql.OrderTermOption) OrderOption
- func BySubject(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the response type in the database. Label = "response" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldExternalId holds the string denoting the externalid field in the database. FieldExternalId = "external_id" // FieldRequestId holds the string denoting the requestid field in the database. FieldRequestId = "request_id" // FieldScenarioId holds the string denoting the scenarioid field in the database. FieldScenarioId = "scenario_id" // FieldFrom holds the string denoting the from field in the database. FieldFrom = "from" // FieldSubject holds the string denoting the subject field in the database. FieldSubject = "subject" // FieldBody holds the string denoting the body field in the database. FieldBody = "body" // FieldDate holds the string denoting the date field in the database. FieldDate = "date" // EdgeRequest holds the string denoting the request edge name in mutations. EdgeRequest = "request" // EdgeScenario holds the string denoting the scenario edge name in mutations. EdgeScenario = "scenario" // EdgeEvaluations holds the string denoting the evaluations edge name in mutations. EdgeEvaluations = "evaluations" // Table holds the table name of the response in the database. Table = "responses" // RequestTable is the table that holds the request relation/edge. RequestTable = "responses" // RequestInverseTable is the table name for the Request entity. // It exists in this package in order to avoid circular dependency with the "request" package. RequestInverseTable = "requests" // RequestColumn is the table column denoting the request relation/edge. RequestColumn = "request_id" // ScenarioTable is the table that holds the scenario relation/edge. ScenarioTable = "responses" // ScenarioInverseTable is the table name for the Scenario entity. // It exists in this package in order to avoid circular dependency with the "scenario" package. ScenarioInverseTable = "scenarios" // ScenarioColumn is the table column denoting the scenario relation/edge. ScenarioColumn = "scenario_id" // EvaluationsTable is the table that holds the evaluations relation/edge. EvaluationsTable = "evaluations" // EvaluationsInverseTable is the table name for the Evaluation entity. // It exists in this package in order to avoid circular dependency with the "evaluation" package. EvaluationsInverseTable = "evaluations" // EvaluationsColumn is the table column denoting the evaluations relation/edge. EvaluationsColumn = "response_id" )
Variables ¶
var Columns = []string{ FieldID, FieldExternalId, FieldRequestId, FieldScenarioId, FieldFrom, FieldSubject, FieldBody, FieldDate, }
Columns holds all SQL columns for response fields.
var ( // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
Functions ¶
func BodyContains ¶
BodyContains applies the Contains predicate on the "body" field.
func BodyContainsFold ¶
BodyContainsFold applies the ContainsFold predicate on the "body" field.
func BodyEqualFold ¶
BodyEqualFold applies the EqualFold predicate on the "body" field.
func BodyHasPrefix ¶
BodyHasPrefix applies the HasPrefix predicate on the "body" field.
func BodyHasSuffix ¶
BodyHasSuffix applies the HasSuffix predicate on the "body" field.
func DateNotNil ¶
DateNotNil applies the NotNil predicate on the "date" field.
func ExternalId ¶
ExternalId applies equality check predicate on the "externalId" field. It's identical to ExternalIdEQ.
func ExternalIdContains ¶
ExternalIdContains applies the Contains predicate on the "externalId" field.
func ExternalIdContainsFold ¶
ExternalIdContainsFold applies the ContainsFold predicate on the "externalId" field.
func ExternalIdEQ ¶
ExternalIdEQ applies the EQ predicate on the "externalId" field.
func ExternalIdEqualFold ¶
ExternalIdEqualFold applies the EqualFold predicate on the "externalId" field.
func ExternalIdGT ¶
ExternalIdGT applies the GT predicate on the "externalId" field.
func ExternalIdGTE ¶
ExternalIdGTE applies the GTE predicate on the "externalId" field.
func ExternalIdHasPrefix ¶
ExternalIdHasPrefix applies the HasPrefix predicate on the "externalId" field.
func ExternalIdHasSuffix ¶
ExternalIdHasSuffix applies the HasSuffix predicate on the "externalId" field.
func ExternalIdIn ¶
ExternalIdIn applies the In predicate on the "externalId" field.
func ExternalIdIsNil ¶
ExternalIdIsNil applies the IsNil predicate on the "externalId" field.
func ExternalIdLT ¶
ExternalIdLT applies the LT predicate on the "externalId" field.
func ExternalIdLTE ¶
ExternalIdLTE applies the LTE predicate on the "externalId" field.
func ExternalIdNEQ ¶
ExternalIdNEQ applies the NEQ predicate on the "externalId" field.
func ExternalIdNotIn ¶
ExternalIdNotIn applies the NotIn predicate on the "externalId" field.
func ExternalIdNotNil ¶
ExternalIdNotNil applies the NotNil predicate on the "externalId" field.
func FromContains ¶
FromContains applies the Contains predicate on the "from" field.
func FromContainsFold ¶
FromContainsFold applies the ContainsFold predicate on the "from" field.
func FromEqualFold ¶
FromEqualFold applies the EqualFold predicate on the "from" field.
func FromHasPrefix ¶
FromHasPrefix applies the HasPrefix predicate on the "from" field.
func FromHasSuffix ¶
FromHasSuffix applies the HasSuffix predicate on the "from" field.
func FromNotNil ¶
FromNotNil applies the NotNil predicate on the "from" field.
func HasEvaluations ¶
HasEvaluations applies the HasEdge predicate on the "evaluations" edge.
func HasEvaluationsWith ¶
func HasEvaluationsWith(preds ...predicate.Evaluation) predicate.Response
HasEvaluationsWith applies the HasEdge predicate on the "evaluations" edge with a given conditions (other predicates).
func HasRequest ¶
HasRequest applies the HasEdge predicate on the "request" edge.
func HasRequestWith ¶
HasRequestWith applies the HasEdge predicate on the "request" edge with a given conditions (other predicates).
func HasScenario ¶
HasScenario applies the HasEdge predicate on the "scenario" edge.
func HasScenarioWith ¶
HasScenarioWith applies the HasEdge predicate on the "scenario" edge with a given conditions (other predicates).
func RequestId ¶
RequestId applies equality check predicate on the "requestId" field. It's identical to RequestIdEQ.
func RequestIdEQ ¶
RequestIdEQ applies the EQ predicate on the "requestId" field.
func RequestIdIn ¶
RequestIdIn applies the In predicate on the "requestId" field.
func RequestIdNEQ ¶
RequestIdNEQ applies the NEQ predicate on the "requestId" field.
func RequestIdNotIn ¶
RequestIdNotIn applies the NotIn predicate on the "requestId" field.
func ScenarioId ¶
ScenarioId applies equality check predicate on the "scenarioId" field. It's identical to ScenarioIdEQ.
func ScenarioIdEQ ¶
ScenarioIdEQ applies the EQ predicate on the "scenarioId" field.
func ScenarioIdIn ¶
ScenarioIdIn applies the In predicate on the "scenarioId" field.
func ScenarioIdNEQ ¶
ScenarioIdNEQ applies the NEQ predicate on the "scenarioId" field.
func ScenarioIdNotIn ¶
ScenarioIdNotIn applies the NotIn predicate on the "scenarioId" field.
func Subject ¶
Subject applies equality check predicate on the "subject" field. It's identical to SubjectEQ.
func SubjectContains ¶
SubjectContains applies the Contains predicate on the "subject" field.
func SubjectContainsFold ¶
SubjectContainsFold applies the ContainsFold predicate on the "subject" field.
func SubjectEqualFold ¶
SubjectEqualFold applies the EqualFold predicate on the "subject" field.
func SubjectGTE ¶
SubjectGTE applies the GTE predicate on the "subject" field.
func SubjectHasPrefix ¶
SubjectHasPrefix applies the HasPrefix predicate on the "subject" field.
func SubjectHasSuffix ¶
SubjectHasSuffix applies the HasSuffix predicate on the "subject" field.
func SubjectIsNil ¶
SubjectIsNil applies the IsNil predicate on the "subject" field.
func SubjectLTE ¶
SubjectLTE applies the LTE predicate on the "subject" field.
func SubjectNEQ ¶
SubjectNEQ applies the NEQ predicate on the "subject" field.
func SubjectNotIn ¶
SubjectNotIn applies the NotIn predicate on the "subject" field.
func SubjectNotNil ¶
SubjectNotNil applies the NotNil predicate on the "subject" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Response queries.
func ByBody ¶
func ByBody(opts ...sql.OrderTermOption) OrderOption
ByBody orders the results by the body field.
func ByDate ¶
func ByDate(opts ...sql.OrderTermOption) OrderOption
ByDate orders the results by the date field.
func ByEvaluations ¶
func ByEvaluations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEvaluations orders the results by evaluations terms.
func ByEvaluationsCount ¶
func ByEvaluationsCount(opts ...sql.OrderTermOption) OrderOption
ByEvaluationsCount orders the results by evaluations count.
func ByExternalId ¶
func ByExternalId(opts ...sql.OrderTermOption) OrderOption
ByExternalId orders the results by the externalId field.
func ByFrom ¶
func ByFrom(opts ...sql.OrderTermOption) OrderOption
ByFrom orders the results by the from field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByRequestField ¶
func ByRequestField(field string, opts ...sql.OrderTermOption) OrderOption
ByRequestField orders the results by request field.
func ByRequestId ¶
func ByRequestId(opts ...sql.OrderTermOption) OrderOption
ByRequestId orders the results by the requestId field.
func ByScenarioField ¶
func ByScenarioField(field string, opts ...sql.OrderTermOption) OrderOption
ByScenarioField orders the results by scenario field.
func ByScenarioId ¶
func ByScenarioId(opts ...sql.OrderTermOption) OrderOption
ByScenarioId orders the results by the scenarioId field.
func BySubject ¶
func BySubject(opts ...sql.OrderTermOption) OrderOption
BySubject orders the results by the subject field.