Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func ExternalId(v string) predicate.User
- func ExternalIdContains(v string) predicate.User
- func ExternalIdContainsFold(v string) predicate.User
- func ExternalIdEQ(v string) predicate.User
- func ExternalIdEqualFold(v string) predicate.User
- func ExternalIdGT(v string) predicate.User
- func ExternalIdGTE(v string) predicate.User
- func ExternalIdHasPrefix(v string) predicate.User
- func ExternalIdHasSuffix(v string) predicate.User
- func ExternalIdIn(vs ...string) predicate.User
- func ExternalIdLT(v string) predicate.User
- func ExternalIdLTE(v string) predicate.User
- func ExternalIdNEQ(v string) predicate.User
- func ExternalIdNotIn(vs ...string) predicate.User
- func HasEvaluations() predicate.User
- func HasEvaluationsWith(preds ...predicate.Evaluation) predicate.User
- func ID(id uuid.UUID) predicate.User
- func IDEQ(id uuid.UUID) predicate.User
- func IDGT(id uuid.UUID) predicate.User
- func IDGTE(id uuid.UUID) predicate.User
- func IDIn(ids ...uuid.UUID) predicate.User
- func IDLT(id uuid.UUID) predicate.User
- func IDLTE(id uuid.UUID) predicate.User
- func IDNEQ(id uuid.UUID) predicate.User
- func IDNotIn(ids ...uuid.UUID) predicate.User
- func Name(v string) predicate.User
- func NameContains(v string) predicate.User
- func NameContainsFold(v string) predicate.User
- func NameEQ(v string) predicate.User
- func NameEqualFold(v string) predicate.User
- func NameGT(v string) predicate.User
- func NameGTE(v string) predicate.User
- func NameHasPrefix(v string) predicate.User
- func NameHasSuffix(v string) predicate.User
- func NameIn(vs ...string) predicate.User
- func NameLT(v string) predicate.User
- func NameLTE(v string) predicate.User
- func NameNEQ(v string) predicate.User
- func NameNotIn(vs ...string) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func Type(v string) predicate.User
- func TypeContains(v string) predicate.User
- func TypeContainsFold(v string) predicate.User
- func TypeEQ(v string) predicate.User
- func TypeEqualFold(v string) predicate.User
- func TypeGT(v string) predicate.User
- func TypeGTE(v string) predicate.User
- func TypeHasPrefix(v string) predicate.User
- func TypeHasSuffix(v string) predicate.User
- func TypeIn(vs ...string) predicate.User
- func TypeIsNil() predicate.User
- func TypeLT(v string) predicate.User
- func TypeLTE(v string) predicate.User
- func TypeNEQ(v string) predicate.User
- func TypeNotIn(vs ...string) predicate.User
- func TypeNotNil() predicate.User
- func ValidColumn(column string) bool
- type OrderOption
- func ByEvaluations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEvaluationsCount(opts ...sql.OrderTermOption) OrderOption
- func ByExternalId(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByType(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldExternalId holds the string denoting the externalid field in the database. FieldExternalId = "external_id" // FieldType holds the string denoting the type field in the database. FieldType = "type" // EdgeEvaluations holds the string denoting the evaluations edge name in mutations. EdgeEvaluations = "evaluations" // Table holds the table name of the user in the database. Table = "users" // EvaluationsTable is the table that holds the evaluations relation/edge. EvaluationsTable = "evaluations" // EvaluationsInverseTable is the table name for the Evaluation entity. // It exists in this package in order to avoid circular dependency with the "evaluation" package. EvaluationsInverseTable = "evaluations" // EvaluationsColumn is the table column denoting the evaluations relation/edge. EvaluationsColumn = "user_id" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // ExternalIdValidator is a validator for the "externalId" field. It is called by the builders before save. ExternalIdValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldName, FieldExternalId, FieldType, }
Columns holds all SQL columns for user fields.
Functions ¶
func ExternalId ¶
ExternalId applies equality check predicate on the "externalId" field. It's identical to ExternalIdEQ.
func ExternalIdContains ¶
ExternalIdContains applies the Contains predicate on the "externalId" field.
func ExternalIdContainsFold ¶
ExternalIdContainsFold applies the ContainsFold predicate on the "externalId" field.
func ExternalIdEQ ¶
ExternalIdEQ applies the EQ predicate on the "externalId" field.
func ExternalIdEqualFold ¶
ExternalIdEqualFold applies the EqualFold predicate on the "externalId" field.
func ExternalIdGT ¶
ExternalIdGT applies the GT predicate on the "externalId" field.
func ExternalIdGTE ¶
ExternalIdGTE applies the GTE predicate on the "externalId" field.
func ExternalIdHasPrefix ¶
ExternalIdHasPrefix applies the HasPrefix predicate on the "externalId" field.
func ExternalIdHasSuffix ¶
ExternalIdHasSuffix applies the HasSuffix predicate on the "externalId" field.
func ExternalIdIn ¶
ExternalIdIn applies the In predicate on the "externalId" field.
func ExternalIdLT ¶
ExternalIdLT applies the LT predicate on the "externalId" field.
func ExternalIdLTE ¶
ExternalIdLTE applies the LTE predicate on the "externalId" field.
func ExternalIdNEQ ¶
ExternalIdNEQ applies the NEQ predicate on the "externalId" field.
func ExternalIdNotIn ¶
ExternalIdNotIn applies the NotIn predicate on the "externalId" field.
func HasEvaluations ¶
HasEvaluations applies the HasEdge predicate on the "evaluations" edge.
func HasEvaluationsWith ¶
func HasEvaluationsWith(preds ...predicate.Evaluation) predicate.User
HasEvaluationsWith applies the HasEdge predicate on the "evaluations" edge with a given conditions (other predicates).
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func TypeContains ¶
TypeContains applies the Contains predicate on the "type" field.
func TypeContainsFold ¶
TypeContainsFold applies the ContainsFold predicate on the "type" field.
func TypeEqualFold ¶
TypeEqualFold applies the EqualFold predicate on the "type" field.
func TypeHasPrefix ¶
TypeHasPrefix applies the HasPrefix predicate on the "type" field.
func TypeHasSuffix ¶
TypeHasSuffix applies the HasSuffix predicate on the "type" field.
func TypeNotNil ¶
TypeNotNil applies the NotNil predicate on the "type" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByEvaluations ¶
func ByEvaluations(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEvaluations orders the results by evaluations terms.
func ByEvaluationsCount ¶
func ByEvaluationsCount(opts ...sql.OrderTermOption) OrderOption
ByEvaluationsCount orders the results by evaluations count.
func ByExternalId ¶
func ByExternalId(opts ...sql.OrderTermOption) OrderOption
ByExternalId orders the results by the externalId field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByType ¶
func ByType(opts ...sql.OrderTermOption) OrderOption
ByType orders the results by the type field.